@@ -1,7 +1,6 @@
 import cgi
 import functools
 import urllib
-import hashlib
 
 from django.core.exceptions import ImproperlyConfigured
 from django.conf import settings
@@ -14,15 +13,13 @@ from django.utils.cache import (
     get_max_age
 )
 
+from fancy_cache.utils import md5
+
 
 REMEMBERED_URLS_KEY = 'fancy-urls'
 LONG_TIME = 60 * 60 * 24 * 30
 
 
-def md5(x):
-    return hashlib.md5(x).hexdigest()
-
-
 class RequestPath(object):
     def __init__(self, request, only_get_keys):
         self.request = request
@@ -30,7 +27,7 @@ class RequestPath(object):
         self._prev_get_full_path = request.get_full_path
 
     def __enter__(self):
-        if self.only_get_keys:
+        if self.only_get_keys is not None:
             # then monkey patch self.request.get_full_path
             self.request.get_full_path = functools.partial(
                 self.get_full_path,
@@ -39,7 +36,7 @@ class RequestPath(object):
             )
 
     def __exit__(self, exc_type, exc_value, traceback):
-        if self.only_get_keys:
+        if self.only_get_keys is not None:
             self.request.get_full_path = self._prev_get_full_path
 
     def get_full_path(self, this, only_keys):
